summaryrefslogtreecommitdiffstats
path: root/kmplot/kmplot/editfunction.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmplot/kmplot/editfunction.h')
-rw-r--r--kmplot/kmplot/editfunction.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kmplot/kmplot/editfunction.h b/kmplot/kmplot/editfunction.h
index 308beadf..ef2613a1 100644
--- a/kmplot/kmplot/editfunction.h
+++ b/kmplot/kmplot/editfunction.h
@@ -39,11 +39,12 @@ class EditIntegralPage;
class EditFunction : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/// @param parser points to the parser instance.
/// @param parent points to the parent widget.
/// @param name of this instance.
- EditFunction( XParser* parser, TQWidget* parent = NULL, const char* name = NULL );
+ EditFunction( XParser* parser, TQWidget* tqparent = NULL, const char* name = NULL );
/// Nothing special to do.
virtual ~EditFunction() {}
/// Fill the dialog's widgets with the properties of the parser function number index.
@@ -39,11 +39,12 @@ class EditIntegralPage;
public:
/// @param parser points to the parser instance.
- /// @param parent points to the parent widget.
+ /// @param tqparent points to the tqparent widget.
/// @param name of this instance.